@@ -86,16 +86,26 @@ struct _AmpConfigFile {
  *---------------------------------------------------------------------------*/
 
 static AmpNodeInfo AmpNodeInformations[] = {
+	{{ANJUTA_PROJECT_GROUP | ANJUTA_PROJECT_ROOT_GROUP,
+	N_("Root"),
+	"text/plain",
+	"autotools-project-root-edit"},
+	ANJUTA_TOKEN_NONE,
+	NULL,
+	NULL},
+
 	{{ANJUTA_PROJECT_GROUP,
 	N_("Group"),
-	"text/plain"},
+	"text/plain",
+	"autotools-project-folder-edit"},
 	ANJUTA_TOKEN_NONE,
 	NULL,
 	NULL},
 
 	{{ANJUTA_PROJECT_SOURCE,
 	N_("Source"),
-	"text/plain"},
+	"text/plain",
+	NULL},
 	ANJUTA_TOKEN_NONE,
 	NULL,
 	NULL},
@@ -104,104 +114,127 @@ static AmpNodeInfo AmpNodeInformations[] = {
 	/* Translator: Unknown here is a target type, if not unknown it can
 	 * be a program or a shared library by example */
 	N_("Unknown"),
-	"text/plain"},
+	"text/plain",
+	"autotools-project-target-edit"},
 	ANJUTA_TOKEN_NONE,
 	NULL,
 	NULL},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY |  ANJUTA_PROJECT_SHAREDLIB,
-	N_("Shared Library"),
-	"application/x-sharedlib"},
+	N_("Shared Library (libtool)"),
+	"application/x-sharedlib",
+	"autotools-project-target-edit"},
+	AM_TOKEN__LTLIBRARIES,
+	"LTLIBRARIES",
+	"lib"},
+
+	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY |  ANJUTA_PROJECT_LT_MODULE,
+	N_("Module (Libtool)"),
+	"application/x-sharedlib",
+	"autotools-project-target-edit"},
 	AM_TOKEN__LTLIBRARIES,
 	"LTLIBRARIES",
 	"lib"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY |  ANJUTA_PROJECT_STATICLIB,
-	N_("Static Library"),
-	"application/x-archive"},
+	N_("Static Library (Libtool)"),
+	"application/x-archive",
+	"autotools-project-target-edit"},
 	AM_TOKEN__LIBRARIES,
 	"LIBRARIES",
 	"lib"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY | ANJUTA_PROJECT_PROGRAM | ANJUTA_PROJECT_EXECUTABLE,
 	N_("Program"),
-	"application/x-executable"},
+	"application/x-executable",
+	"autotools-project-target-edit"},
 	AM_TOKEN__PROGRAMS,
 	"PROGRAMS",
 	"bin"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PYTHON,
 	N_("Python Module"),
-	"application/x-python"},
+	"application/x-python",
+	"autotools-project-target-edit"},
 	AM_TOKEN__PYTHON,
 	"PYTHON",
 	"python"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_JAVA,
 	N_("Java Module"),
-	"application/x-java"},
+	"application/x-java",
+	"autotools-project-target-edit"},
 	AM_TOKEN__JAVA,
 	"JAVA",
 	"java"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_LISP,
 	N_("Lisp Module"),
-	"text/plain"},
+	"text/plain",
+	"autotools-project-target-edit"},
 	AM_TOKEN__LISP,
 	"LISP",
 	"lisp"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_HEADER,
 	N_("Header Files"),
-	"text/x-chdr"},
+	"text/x-chdr",
+	"autotools-project-target-edit"},
 	AM_TOKEN__HEADERS,
 	"HEADERS",
 	"include"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_MAN,
 	N_("Man Documentation"),
-	"text/x-troff-man"},
+	"text/x-troff-man",
+	"autotools-project-target-edit"},
 	AM_TOKEN__MANS,
 	"MANS",
 	"man"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_INFO,
 	N_("Info Documentation"),
-	"application/x-tex-info"},
+	"application/x-tex-info",
+	"autotools-project-target-edit"},
 	AM_TOKEN__TEXINFOS,
 	"TEXINFOS",
 	"info"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_DATA,
 	N_("Miscellaneous Data"),
-	"application/octet-stream"},
+	"application/octet-stream",
+	"autotools-project-target-edit"},
 	AM_TOKEN__DATA,
 	"DATA",
 	"data"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_SCRIPT,
 	N_("Script"),
-	"text/x-shellscript"},
+	"text/x-shellscript",
+	"autotools-project-target-edit"},
 	AM_TOKEN__SCRIPTS,
 	"SCRIPTS",
 	"bin"},
 
 	{{ANJUTA_PROJECT_MODULE,
 	N_("Module"),
-	""},
+	"",
+	NULL},
 	ANJUTA_TOKEN_NONE,
 	NULL,
 	NULL},
 
 	{{ANJUTA_PROJECT_PACKAGE,
 	N_("Package"),
-	""},
+	"",
+	NULL},
 	ANJUTA_TOKEN_NONE,
 	NULL,
 	NULL},
 
 	{{ANJUTA_PROJECT_UNKNOWN,
 	NULL,
+	NULL,
 	NULL},
 	ANJUTA_TOKEN_NONE,
 	NULL,
@@ -1679,6 +1712,7 @@ amp_project_load_root (AmpProject *project, GError **error)
 		{
 			g_set_error (error, IANJUTA_PROJECT_ERROR,
 						IANJUTA_PROJECT_ERROR_PROJECT_MALFORMED,
+						"%s",
 						_("Unable to parse project file"));
 		}
 
@@ -1850,6 +1884,7 @@ amp_project_get_node_info (AmpProject *project, GError **error)
 typedef struct _AmpMovePacket {
 	AmpProject *project;
 	GFile *old_root_file;
+	GFile *new_root_file;
 } AmpMovePacket;
 
 static void
@@ -1857,7 +1892,7 @@ foreach_node_move (AnjutaProjectNode *g_node, gpointer data)
 {
 	AmpProject *project = ((AmpMovePacket *)data)->project;
 	GFile *old_root_file = ((AmpMovePacket *)data)->old_root_file;
-	GFile *root_file = anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (project));
+	GFile *new_root_file = ((AmpMovePacket *)data)->new_root_file;
 	gchar *relative;
 	GFile *new_file;
 
@@ -1865,7 +1900,7 @@ foreach_node_move (AnjutaProjectNode *g_node, gpointer data)
 	{
 	case ANJUTA_PROJECT_GROUP:
 		relative = get_relative_path (old_root_file, anjuta_project_node_get_file (g_node));
-		new_file = g_file_resolve_relative_path (root_file, relative);
+		new_file = g_file_resolve_relative_path (new_root_file, relative);
 		g_free (relative);
 		amp_group_node_set_file (AMP_GROUP_NODE (g_node), new_file);
 		g_object_unref (new_file);
@@ -1874,7 +1909,7 @@ foreach_node_move (AnjutaProjectNode *g_node, gpointer data)
 		break;
 	case ANJUTA_PROJECT_SOURCE:
 		relative = get_relative_path (old_root_file, anjuta_project_node_get_file (g_node));
-		new_file = g_file_resolve_relative_path (root_file, relative);
+		new_file = g_file_resolve_relative_path (new_root_file, relative);
 		g_free (relative);
 		amp_source_node_set_file (AMP_SOURCE_NODE (g_node), new_file);
 		g_object_unref (new_file);
@@ -1888,7 +1923,6 @@ gboolean
 amp_project_move (AmpProject *project, const gchar *path)
 {
 	GFile *new_file;
-	GFile *root_file;
 	gchar *relative;
 	GList *list;
 	gpointer key;
@@ -1899,11 +1933,7 @@ amp_project_move (AmpProject *project, const gchar *path)
 
 	/* Change project root directory */
 	packet.old_root_file = g_object_ref (anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (project)));
-	root_file = g_file_new_for_path (path);
-	amp_root_node_set_file (AMP_ROOT_NODE (project), root_file);
-
-	/* Root node is a group too */
-	foreach_node_move (ANJUTA_PROJECT_NODE (project), &packet);
+	packet.new_root_file = g_file_new_for_path (path);
 
 	/* Change project root directory in groups */
 	old_hash = project->groups;
@@ -1917,7 +1947,7 @@ amp_project_move (AmpProject *project, const gchar *path)
 		AnjutaTokenFile *tfile = (AnjutaTokenFile *)list->data;
 
 		relative = get_relative_path (packet.old_root_file, anjuta_token_file_get_file (tfile));
-		new_file = g_file_resolve_relative_path (root_file, relative);
+		new_file = g_file_resolve_relative_path (packet.new_root_file, relative);
 		g_free (relative);
 		anjuta_token_file_move (tfile, new_file);
 	}
@@ -1929,7 +1959,7 @@ amp_project_move (AmpProject *project, const gchar *path)
 	while (g_hash_table_iter_next (&iter, &key, (gpointer *)&cfg))
 	{
 		relative = get_relative_path (packet.old_root_file, cfg->file);
-		new_file = g_file_resolve_relative_path (root_file, relative);
+		new_file = g_file_resolve_relative_path (packet.new_root_file, relative);
 		g_free (relative);
 		g_object_unref (cfg->file);
 		cfg->file = new_file;
@@ -1939,9 +1969,8 @@ amp_project_move (AmpProject *project, const gchar *path)
 	g_hash_table_steal_all (old_hash);
 	g_hash_table_destroy (old_hash);
 
-
-	g_object_unref (root_file);
 	g_object_unref (packet.old_root_file);
+	g_object_unref (packet.new_root_file);
 
 	return TRUE;
 }
@@ -2175,6 +2204,30 @@ amp_add_work (PmJob *job)
 	gboolean ok;
 
 	ok = amp_node_write (AMP_NODE (job->node), parent, AMP_PROJECT (job->user_data), &job->error);
+	/* Add new node properties if existing */
+	if (ok)
+	{
+		GList *item;
+
+		for (item = anjuta_project_node_get_properties (ANJUTA_PROJECT_NODE (job->node)); item != NULL; item = g_list_next (item))
+		{
+			AnjutaProjectProperty *property = (AnjutaProjectProperty *)item->data;
+			gint flags;
+
+			flags = ((AmpPropertyInfo *)property->info)->flags;
+			if (flags & AM_PROPERTY_IN_CONFIGURE)
+			{
+				ok = ok && amp_project_update_ac_property (AMP_PROJECT (job->user_data), property);
+			}
+			else if (flags & AM_PROPERTY_IN_MAKEFILE)
+			{
+				if (((AnjutaProjectPropertyInfo *)property->info)->flags & ANJUTA_PROJECT_PROPERTY_READ_WRITE)
+				{
+					ok = ok && amp_project_update_am_property (AMP_PROJECT (job->user_data), job->node, property);
+				}
+			}
+		}
+	}
 
 	return ok;
 }
