@@ -37,6 +37,7 @@
 #include "amp-source.h"
 
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/interfaces/ianjuta-project.h>
 
 #include <glib/gi18n.h>
 
@@ -45,6 +46,32 @@
 #include <ctype.h>
 
 
+/* Helper functions
+ *---------------------------------------------------------------------------*/
+
+void
+amp_set_error (GError **error, gint code, const gchar *message)
+{
+        if (error != NULL) {
+                if (*error != NULL) {
+                        gchar *tmp;
+
+                        /* error already created, just change the code
+                         * and prepend the string */
+                        (*error)->code = code;
+                        tmp = (*error)->message;
+                        (*error)->message = g_strconcat (message, "\n\n", tmp, NULL);
+                        g_free (tmp);
+
+                } else {
+                        *error = g_error_new_literal (IANJUTA_PROJECT_ERROR,
+                                                      code,
+                                                      message);
+                }
+        }
+}
+
+
 /* Public functions
  *---------------------------------------------------------------------------*/
 
