@@ -42,9 +42,11 @@
 #define GLADE_FILE  PACKAGE_DATA_DIR "/glade/pm_dialogs.ui"
 
 #define ANJUTA_MANUAL	"anjuta-manual"
-#define ADD_SOURCE_HELP	"anjuta-project-files"
-#define ADD_TARGET_HELP	"project-manager-target"
-#define ADD_PACKAGE_HELP "project-manager-module"
+#define ADD_SOURCE_HELP	"project-manager-source-add"
+#define ADD_TARGET_HELP	"project-manager-target-add"
+#define ADD_PACKAGE_HELP "project-manager-module-new"
+#define ADD_MODULE_HELP "project-manager-module-add"
+#define ADD_FOLDER_HELP "project-manager-folder-add"
 
 
 /* Types
@@ -61,6 +63,8 @@ typedef struct _PropertiesTable
 	GtkWidget *extra;
 	GbfTreeData *data;
 	AnjutaProjectNode *node;
+	GtkWidget *help_button;
+	const gchar *help_id;
 	GList *properties;
 } PropertiesTable;
 
@@ -194,20 +198,26 @@ parent_filter_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 
 	gtk_tree_model_get (model, iter,
 						GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
-	node = data == NULL ? NULL : gbf_tree_data_get_node (data);
-	if (node != NULL)
+	if (data->shortcut != NULL)
 	{
-		if (anjuta_project_node_get_state (node) & need)
+		visible = FALSE;
+	}
+	else
+	{
+		node = data == NULL ? NULL : gbf_tree_data_get_node (data);
+		if (node != NULL)
 		{
-			/* Current node can be used as parent */
-			visible = TRUE;
-		}
-		else if (anjuta_project_node_get_node_type (node) == type)
-		{
-			/* Check if node can be used as sibling */
-			parent = anjuta_project_node_parent (node);
-			visible = anjuta_project_node_get_state (parent) & need ? TRUE : FALSE;
-
+			if (anjuta_project_node_get_state (node) & need)
+			{
+				/* Current node can be used as parent */
+				visible = TRUE;
+			}
+			else if (anjuta_project_node_get_node_type (node) == type)
+			{
+				/* Check if node can be used as sibling */
+				parent = anjuta_project_node_parent (node);
+				visible = anjuta_project_node_get_state (parent) & need ? TRUE : FALSE;
+			}
 		}
 	}
 
@@ -551,7 +561,14 @@ update_properties (PropertiesTable *table)
 		title = _("Project properties");
 		break;
 	case ANJUTA_PROJECT_GROUP:
-		title = _("Folder properties");
+		if ((anjuta_project_node_get_full_type (table->node) & ANJUTA_PROJECT_ID_MASK) == ANJUTA_PROJECT_ROOT_GROUP)
+		{
+			title = _("Project properties");
+		}
+		else
+		{
+			title = _("Folder properties");
+		}
 		break;
 	case ANJUTA_PROJECT_TARGET:
 		title = _("Target properties");
@@ -622,6 +639,18 @@ update_properties (PropertiesTable *table)
 		add_label (_("Type:"), anjuta_project_node_info_name (node_info), table->main, &main_pos);
 	}
 
+	/* Show help button if existing */
+	if ((node_info != NULL) && (anjuta_project_node_info_property_help_id (node_info) != NULL))
+	{
+		table->help_id = anjuta_project_node_info_property_help_id (node_info);
+		gtk_widget_show (table->help_button);
+	}
+	else
+	{
+		table->help_id = NULL;
+		gtk_widget_hide (table->help_button);
+	}
+
 	/* Display other node properties */
 	single = FALSE;
 
@@ -745,6 +774,11 @@ on_properties_dialog_response (GtkWidget *dialog,
 			}
 		}
 	}
+	else if (id == GTK_RESPONSE_HELP)
+	{
+		anjuta_util_help_display (GTK_WIDGET (dialog), ANJUTA_MANUAL, table->help_id);
+		return;
+	}
 	g_list_foreach (table->properties, (GFunc)pm_property_entry_free, NULL);
 	g_free (table);
 	gtk_widget_destroy (dialog);
@@ -787,7 +821,6 @@ static GtkWidget *
 pm_project_create_properties_dialog (AnjutaPmProject *project, GtkWindow *parent, GbfProjectView *view, GbfTreeData *data, GtkTreeIter *selected)
 {
 	PropertiesTable *table;
-	GtkWidget *dialog = NULL;
 	GtkBuilder *bxml;
 	GtkWidget *node_combo;
 	GtkTreeIter iter;
@@ -802,12 +835,14 @@ pm_project_create_properties_dialog (AnjutaPmProject *project, GtkWindow *parent
 	table->node = gbf_tree_data_get_node (data);
 	table->project = project;
 	anjuta_util_builder_get_objects (bxml,
+	                                "property_dialog", &table->dialog,
 									"properties", &table->table,
 	                                "nodes_combo", &node_combo,
 									"head_table", &table->head,
 									"main_table", &table->main,
 									"extra_table", &table->extra,
 									"extra_expand", &table->expand,
+	                                "property_help_button", &table->help_button,
 									NULL);
 	g_object_ref (table->table);
 	g_object_unref (bxml);
@@ -826,27 +861,16 @@ pm_project_create_properties_dialog (AnjutaPmProject *project, GtkWindow *parent
 					G_CALLBACK (on_node_changed),
 					table);
 
-	dialog = gtk_dialog_new_with_buttons (NULL,
-						   parent,
-						   GTK_DIALOG_DESTROY_WITH_PARENT,
-						   GTK_STOCK_CANCEL,
-						   GTK_RESPONSE_CANCEL,
-						   GTK_STOCK_APPLY,
-						   GTK_RESPONSE_APPLY, NULL);
-	table->dialog = dialog;
-
 	update_properties (table);
 
-	g_signal_connect (dialog, "response",
+	g_signal_connect (table->dialog, "response",
 					G_CALLBACK (on_properties_dialog_response),
 					table);
 
-	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))),
-					table->table);
-	gtk_window_set_default_size (GTK_WINDOW (dialog), 450, -1);
-	gtk_widget_show (dialog);
+	gtk_window_set_default_size (GTK_WINDOW (table->dialog), 450, -1);
+	gtk_widget_show (table->dialog);
 
-	return dialog;
+	return table->dialog;
 }
 
 
@@ -994,6 +1018,9 @@ anjuta_pm_project_new_group (ProjectManagerPlugin *plugin, GtkWindow *parent, Gt
 				g_free (name);
 				break;
 			}
+			case GTK_RESPONSE_HELP:
+				anjuta_util_help_display (GTK_WIDGET (dialog), ANJUTA_MANUAL, ADD_FOLDER_HELP);
+				break;
 			default:
 				finished = TRUE;
 				break;
@@ -1592,6 +1619,16 @@ on_cursor_changed(GtkTreeView* view, gpointer data)
 		gtk_widget_set_sensitive(button, FALSE);
 }
 
+static void
+on_new_library(GtkButton *button, gpointer user_data)
+{
+	ProjectManagerPlugin *plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (user_data);
+	anjuta_pm_project_new_package (plugin,
+	                               get_plugin_parent_window (plugin),
+	                               NULL,
+	                               NULL);
+}
+
 GList*
 anjuta_pm_project_new_module (ProjectManagerPlugin *plugin,
                              GtkWindow          *parent,
@@ -1649,6 +1686,8 @@ anjuta_pm_project_new_module (ProjectManagerPlugin *plugin,
 	}
 	g_signal_connect (G_OBJECT(modules_view), "cursor-changed",
 						G_CALLBACK(on_cursor_changed), ok_button);
+	g_signal_connect (G_OBJECT(new_button), "clicked",
+	                	G_CALLBACK(on_new_library), plugin);
 
 
 	if (parent)
@@ -1664,12 +1703,6 @@ anjuta_pm_project_new_module (ProjectManagerPlugin *plugin,
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 
 		switch (response) {
-			case 1:
-			{
-				anjuta_pm_project_new_package (plugin, parent, NULL, NULL);
-
-				break;
-			}
 			case GTK_RESPONSE_OK:
 			{
 				GFile *target_file;
@@ -1726,6 +1759,9 @@ anjuta_pm_project_new_module (ProjectManagerPlugin *plugin,
 
 				break;
 			}
+			case GTK_RESPONSE_HELP:
+				anjuta_util_help_display (GTK_WIDGET (dialog), ANJUTA_MANUAL, ADD_MODULE_HELP);
+				break;
 			default:
 				finished = TRUE;
 				break;
