@@ -35,6 +35,7 @@
 
 #include "project-util.h"
 #include "dialogs.h"
+#include "project-chooser.h"
 
 #include "plugin.h"
 
@@ -68,20 +69,6 @@ static gboolean file_is_inside_project (ProjectManagerPlugin *plugin,
 									   GFile *uri);
 static void project_manager_plugin_close (ProjectManagerPlugin *plugin);
 
-static GtkWindow*
-get_plugin_parent_window (ProjectManagerPlugin *plugin)
-{
-	GtkWindow *win;
-	GtkWidget *toplevel;
-
-	toplevel = gtk_widget_get_toplevel (plugin->scrolledwindow);
-	if (toplevel && GTK_IS_WINDOW (toplevel))
-		win = GTK_WINDOW (toplevel);
-	else
-		win = GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell);
-	return win;
-}
-
 static void
 update_title (ProjectManagerPlugin* plugin, const gchar *project_uri)
 {
@@ -89,8 +76,8 @@ update_title (ProjectManagerPlugin* plugin, const gchar *project_uri)
 	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
 	if (project_uri)
 	{
-		GFile *file;
 		GFileInfo *file_info;
+		GFile *file;
 
 		file = g_file_new_for_uri (project_uri);
 		file_info = g_file_query_info (file,
@@ -168,12 +155,12 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 	 * we should not save the current project uri, because project
 	 * sessions are loaded when the project has already been loaded.
 	 */
-	if (plugin->project_uri && !plugin->session_by_me)
+	if (plugin->project_file && !plugin->session_by_me)
 	{
 		list = anjuta_session_get_string_list (session,
 												"File Loader",
 												"Files");
-		list = g_list_append (list, g_strdup (plugin->project_uri));
+		list = g_list_append (list, anjuta_session_get_relative_uri_from_file (session, plugin->project_file, NULL));
 		anjuta_session_set_string_list (session, "File Loader",
 										"Files", list);
 		g_list_foreach (list, (GFunc)g_free, NULL);
@@ -222,7 +209,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *se
 static void
 on_shell_exiting (AnjutaShell *shell, ProjectManagerPlugin *plugin)
 {
-	if (plugin->project_uri)
+	if (plugin->project_file)
 	{
 		/* Also make sure we save the project session also */
 		project_manager_save_session (plugin);
@@ -241,7 +228,7 @@ on_close_project_idle (gpointer plugin)
 static void
 on_close_project (GtkAction *action, ProjectManagerPlugin *plugin)
 {
-	if (plugin->project_uri)
+	if (plugin->project_file)
 		plugin->close_project_idle = g_idle_add (on_close_project_idle, plugin);
 }
 
@@ -386,6 +373,21 @@ update_operation_begin (ProjectManagerPlugin *plugin)
 										  NULL);
 }
 
+GtkWindow*
+get_plugin_parent_window (ProjectManagerPlugin *plugin)
+{
+	GtkWindow *win;
+	GtkWidget *toplevel;
+
+	toplevel = gtk_widget_get_toplevel (plugin->scrolledwindow);
+	if (toplevel && GTK_IS_WINDOW (toplevel))
+		win = GTK_WINDOW (toplevel);
+	else
+		win = GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell);
+	return win;
+}
+
+
 /* GUI callbacks
  *---------------------------------------------------------------------------*/
 
@@ -1509,8 +1511,8 @@ on_profile_descoped (AnjutaProfileManager *profile_manager,
 	project_manager_unload_gbf (plugin);
 
 	g_free (plugin->project_root_uri);
-	g_free (plugin->project_uri);
-	plugin->project_uri = NULL;
+	if (plugin->project_file) g_object_unref (plugin->project_file);
+	plugin->project_file = NULL;
 	plugin->project_root_uri = NULL;
 
 	update_title (ANJUTA_PLUGIN_PROJECT_MANAGER (plugin), NULL);
@@ -1741,7 +1743,7 @@ project_manager_plugin_instance_init (GObject *obj)
 	plugin->pre_update_targets = NULL;
 	plugin->pre_update_groups = NULL;
 	plugin->project_root_uri = NULL;
-	plugin->project_uri = NULL;
+	plugin->project_file = NULL;
 	plugin->fm_current_uri = NULL;
 	plugin->current_editor_uri = NULL;
 	plugin->session_by_me = FALSE;
@@ -1893,35 +1895,83 @@ get_element_type (ProjectManagerPlugin *plugin, GFile *element)
 }
 
 static GList*
-iproject_manager_get_elements (IAnjutaProjectManager *project_manager,
-							   AnjutaProjectNodeType element_type,
+iproject_manager_get_children (IAnjutaProjectManager *project_manager,
+							   GFile *parent,
+                               gint children_type,
 							   GError **err)
 {
-	GList *nodes, *node;
 	ProjectManagerPlugin *plugin;
+	GList *children = NULL;
 
 	g_return_val_if_fail (ANJUTA_IS_PLUGIN (project_manager), NULL);
 
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (G_OBJECT (project_manager));
-
-	/* Get all nodes */
-	nodes = gbf_project_util_node_all (anjuta_pm_project_get_root (plugin->project), element_type);
-
-	/* Replace all nodes by their corresponding URI */
-	for (node = g_list_first (nodes); node != NULL; node = g_list_next (node))
+	if (plugin->project !=  NULL)
 	{
-		if (anjuta_project_node_get_node_type (ANJUTA_PROJECT_NODE (node->data)) == ANJUTA_PROJECT_TARGET)
+		AnjutaProjectNode *root;
+
+		root = anjuta_pm_project_get_root  (plugin->project);
+		if (root != NULL)
 		{
-			/* Take care of different build directory */
-			node->data = get_element_file_from_node (plugin, ANJUTA_PROJECT_NODE (node->data), IANJUTA_BUILDER_ROOT_URI);
-		}
-		else
-		{
-            node->data = g_object_ref (anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (node->data)));
+			/* Get parent */
+			if (parent != NULL) root = get_node_from_file (root, parent);
+			if (root != NULL)
+			{
+				/* Get all nodes */
+				GList *node;
+				GHashTable *included_hash;
+
+				children = gbf_project_util_node_all (root, children_type);
+
+				/* Replace all nodes by their corresponding file and remove duplicate */
+				included_hash = g_hash_table_new ((GHashFunc)g_file_hash, (GEqualFunc)g_file_equal);
+				node = g_list_first (children);
+				while (node != NULL)
+				{
+					GFile *file;
+
+					if (anjuta_project_node_get_node_type (ANJUTA_PROJECT_NODE (node->data)) == ANJUTA_PROJECT_TARGET)
+					{
+						/* Take care of different build directory */
+						file = get_element_file_from_node (plugin, ANJUTA_PROJECT_NODE (node->data), IANJUTA_BUILDER_ROOT_URI);
+					}
+					else
+					{
+            			file = g_object_ref (anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (node->data)));
+					}
+
+					if (g_hash_table_lookup (included_hash, file) != NULL)
+					{
+						/* Already included, remove */
+						GList *next = g_list_next (node);
+
+						children = g_list_delete_link (children, node);
+						g_object_unref (file);
+						node = next;
+					}
+					else
+					{
+						/* Keep in the list */
+						g_hash_table_replace (included_hash, file, file);
+
+						node->data = file;
+						node = g_list_next (node);
+					}
+				}
+				g_hash_table_destroy (included_hash);
+			}
 		}
 	}
 
-	return nodes;
+	return children;
+}
+
+static GList*
+iproject_manager_get_elements (IAnjutaProjectManager *project_manager,
+							   AnjutaProjectNodeType element_type,
+							   GError **err)
+{
+	return ianjuta_project_manager_get_children (project_manager, NULL, element_type, err);
 }
 
 static AnjutaProjectNodeType
@@ -2006,20 +2056,6 @@ iproject_manager_get_parent (IAnjutaProjectManager *project_manager,
 	return file;
 }
 
-static GList*
-iproject_manager_get_children (IAnjutaProjectManager *project_manager,
-							   GFile *element,
-							   GError **err)
-{
-	ProjectManagerPlugin *plugin;
-
-	g_return_val_if_fail (ANJUTA_IS_PLUGIN (project_manager), NULL);
-
-	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (G_OBJECT (project_manager));
-	/* FIXME: */
-	return NULL;
-}
-
 static GFile*
 iproject_manager_get_selected (IAnjutaProjectManager *project_manager,
 							   GError **err)
@@ -2378,9 +2414,9 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 
 	/* Set project uri */
 	g_free (plugin->project_root_uri);
-	g_free (plugin->project_uri);
+	if (plugin->project_file) g_object_unref (plugin->project_file);
 
-	plugin->project_uri = g_file_get_uri (file);
+	plugin->project_file = g_object_ref (file);
 	plugin->project_root_uri = g_file_get_uri (project_root);
 	g_object_unref (project_root);
 
@@ -2421,8 +2457,9 @@ ifile_iface_init(IAnjutaFileIface *iface)
 }
 
 ANJUTA_PLUGIN_BEGIN (ProjectManagerPlugin, project_manager_plugin);
-ANJUTA_PLUGIN_ADD_INTERFACE (iproject_manager, IANJUTA_TYPE_PROJECT_MANAGER);
-ANJUTA_PLUGIN_ADD_INTERFACE (ifile, IANJUTA_TYPE_FILE);
+	ANJUTA_PLUGIN_ADD_INTERFACE (iproject_manager, IANJUTA_TYPE_PROJECT_MANAGER);
+	ANJUTA_PLUGIN_ADD_INTERFACE (ifile, IANJUTA_TYPE_FILE);
+	anjuta_pm_chooser_button_register (module);
 ANJUTA_PLUGIN_END;
 
 ANJUTA_SIMPLE_PLUGIN (ProjectManagerPlugin, project_manager_plugin);
