@@ -58,6 +58,7 @@ struct _NPWProperty {
 	NPWPropertyType type;
 	NPWPropertyType restriction;
 	NPWPropertyOptions options;
+	gdouble range[3];
 	gchar* label;
 	gchar* description;
 	gchar* defvalue;
@@ -87,7 +88,8 @@ static const gchar* NPWPropertyTypeString[] = {
 
 static const gchar* NPWPropertyRestrictionString[] = {
 	"filename",
-	"directory"
+	"directory",
+	"printable"
 };
 
 /* Item object
@@ -97,12 +99,12 @@ static NPWItem*
 npw_item_new (const gchar *name, const gchar *label, gint language)
 {
 	NPWItem *item;
-	
+
 	item = g_slice_new (NPWItem);
 	item->name = g_strdup (name);
 	item->label = g_strdup (label);
 	item->language = language;
-	
+
 	return item;
 }
 
@@ -160,7 +162,7 @@ npw_property_restriction_from_string (const gchar* restriction)
 				return (NPWPropertyRestriction)(i + 1);
 			}
 		}
-	}	
+	}
 
 	return NPW_NO_RESTRICTION;
 }
@@ -283,7 +285,17 @@ npw_property_is_valid_restriction (const NPWProperty* prop)
 				return FALSE;
 		}
 		break;
+	case NPW_PRINTABLE_RESTRICTION:
+		value = npw_property_get_value (prop);
 
+		if (value == NULL) return TRUE;
+
+		/* All characters should be ASCII printable character */
+		for (value++; *value != '\0'; value++)
+		{
+			if (!g_ascii_isprint (*value)) return FALSE;
+		}
+		break;
 	default:
 		break;
 	}
@@ -334,7 +346,7 @@ cb_browse_button_clicked (GtkButton *button, NPWProperty* prop)
 {
 	GtkWidget *dialog;
 	gchar *path;
-	
+
 	switch (prop->type)
 	{
 	case NPW_DIRECTORY_PROPERTY:
@@ -387,12 +399,12 @@ cb_preview_update (GtkFileChooser *fc,
 		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
 
 		gtk_file_chooser_set_preview_widget_active (fc, pixbuf != NULL);
-		
+
 		if (pixbuf) {
 			gtk_image_set_from_pixbuf (preview, pixbuf);
 			g_object_unref (pixbuf);
 		}
-		
+
 		g_free (filename);
 	}
 }
@@ -407,7 +419,7 @@ cb_icon_button_clicked (GtkButton *button, NPWProperty* prop)
 
 	dialog = gtk_file_chooser_dialog_new (_("Select an Image File"),
 											GTK_WINDOW (gtk_widget_get_ancestor (prop->widget, GTK_TYPE_WINDOW)),
-					      					GTK_FILE_CHOOSER_ACTION_OPEN, 
+					      					GTK_FILE_CHOOSER_ACTION_OPEN,
 					      					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 					      					NULL);
@@ -447,15 +459,17 @@ npw_property_create_widget (NPWProperty* prop)
 	switch (prop->type)
 	{
 	case NPW_BOOLEAN_PROPERTY:
-		entry = gtk_switch_new ();
+		entry = gtk_check_button_new ();
 		if (value)
 		{
-			gtk_switch_set_active (GTK_SWITCH (entry),
-			                      (gboolean)atoi (value));
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (entry),
+			                              (gboolean)atoi (value));
 		}
 		break;
 	case NPW_INTEGER_PROPERTY:
-		entry = gtk_spin_button_new (NULL, 1, 0);
+		if (prop->range[1] == 0) prop->range[1] = 10000;
+		if (prop->range[2] == 0) prop->range[2] = 1;
+		entry = gtk_spin_button_new_with_range (prop->range[0], prop->range[1], prop->range[2]);
 		if (value)
 		{
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (entry), atoi (value));
@@ -470,15 +484,15 @@ npw_property_create_widget (NPWProperty* prop)
 		if ((prop->options & NPW_EXIST_SET_OPTION) && !(prop->options & NPW_EXIST_OPTION))
 		{
 			GtkWidget *button;
-			
+
 			// Use an entry box and a browse button as GtkFileChooserButton
 			// allow to select only existing file
 			widget = gtk_hbox_new (FALSE, 3);
-			
+
 			entry = gtk_entry_new ();
 			if (value) gtk_entry_set_text (GTK_ENTRY (entry), value);
 			gtk_container_add (GTK_CONTAINER (widget), entry);
-			
+
 			button = gtk_button_new_from_stock (GTK_STOCK_OPEN);
 			g_signal_connect (button, "clicked", G_CALLBACK (cb_browse_button_clicked), prop);
 			gtk_container_add (GTK_CONTAINER (widget), button);
@@ -495,7 +509,7 @@ npw_property_create_widget (NPWProperty* prop)
 				entry = gtk_file_chooser_button_new (_("Choose file"),
 												 GTK_FILE_CHOOSER_ACTION_OPEN);
 			}
-				
+
 			if (value)
 			{
 				GFile *file = g_file_parse_name (value);
@@ -565,7 +579,7 @@ npw_property_create_widget (NPWProperty* prop)
 		return NULL;
 	}
 	prop->widget = entry;
-	
+
 
 	return widget == NULL ? entry : widget;
 }
@@ -620,6 +634,20 @@ npw_property_set_default (NPWProperty* prop, const gchar* value)
 	}
 }
 
+gboolean
+npw_property_set_range (NPWProperty* prop, NPWPropertyRangeMark mark, const gchar* value)
+{
+	char *end;
+	double d;
+	gboolean ok;
+
+	d = strtod (value,  &end);
+	ok = (*end == ':')  || (*end == '\0');
+	if (ok) prop->range[mark] = d;
+
+	return ok;
+}
+
 static gboolean
 npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 {
@@ -637,7 +665,7 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 		value = alloc_value;
 		break;
 	case NPW_BOOLEAN_PROPERTY:
-		alloc_value = g_strdup_printf("%d", gtk_switch_get_active (GTK_SWITCH (prop->widget)));
+		alloc_value = g_strdup_printf("%d", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prop->widget)));
 		value = alloc_value;
 		break;
 	case NPW_STRING_PROPERTY:
@@ -660,7 +688,7 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 		}
 		break;
 	case NPW_ICON_PROPERTY:
-		g_object_get (G_OBJECT (gtk_button_get_image (GTK_BUTTON (prop->widget))), "file", &alloc_value, NULL);	
+		g_object_get (G_OBJECT (gtk_button_get_image (GTK_BUTTON (prop->widget))), "file", &alloc_value, NULL);
 		value = alloc_value;
 		break;
 	case NPW_LIST_PROPERTY:
@@ -679,7 +707,7 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 		break;
 	}
 	case NPW_PACKAGE_PROPERTY:
-		packages = 
+		packages =
 			anjuta_pkg_config_chooser_get_active_packages (ANJUTA_PKG_CONFIG_CHOOSER (prop->widget));
 		str_value = NULL;
 		for (node = packages; node != NULL; node = g_list_next (node))
@@ -691,10 +719,13 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 			else
 				str_value = g_string_new (node->data);
 		}
-		value = str_value->str;
-		g_string_free (str_value, FALSE);
+		if (str_value != NULL)
+		{
+			value = str_value->str;
+			g_string_free (str_value, FALSE);
+		}
 		g_list_foreach (packages, (GFunc) g_free, NULL);
-		g_list_free (packages);	
+		g_list_free (packages);
 		break;
 	default:
 		/* Hidden property */
@@ -707,7 +738,7 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 	{
 		tag |= NPW_DEFAULT_VALUE;
 	}
-	
+
 	ok = npw_value_set_value (prop->value, value, tag);
 	if (alloc_value != NULL) g_free (alloc_value);
 
@@ -746,7 +777,7 @@ npw_property_get_value (const NPWProperty* prop)
 	{
 		/* Only value entered by user could replace default value */
 		return npw_value_get_value (prop->value);
-	}	
+	}
 }
 
 gboolean
@@ -760,7 +791,7 @@ npw_property_add_list_item (NPWProperty* prop, const gchar* name, const gchar* l
 	if (find != NULL)
 	{
 		NPWItem* old_item = (NPWItem *)find->data;
-		
+
 		if (old_item->language <= item->language)
 		{
 			npw_item_free ((NPWItem *)find->data);
@@ -951,7 +982,7 @@ NPWProperty *
 npw_page_add_property (NPWPage* page, NPWProperty *prop)
 {
 	GList *find;
-	
+
 	find = g_list_find_custom (page->properties, prop, (GCompareFunc)npw_property_compare);
 	if (find == NULL)
 	{
@@ -960,7 +991,7 @@ npw_page_add_property (NPWPage* page, NPWProperty *prop)
 	else
 	{
 		NPWProperty* old_prop = (NPWProperty *)find->data;
-		
+
 		if (old_prop->language <= prop->language)
 		{
 			npw_property_free (old_prop);
@@ -972,6 +1003,6 @@ npw_page_add_property (NPWPage* page, NPWProperty *prop)
 			prop = old_prop;
 		}
 	}
-	
+
 	return prop;
 }
